"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApexLexer_1 = require("../ApexLexer");
const ApexParser_1 = require("../ApexParser");
const CaseInsensitiveInputStream_1 = require("../CaseInsensitiveInputStream");
const antlr4ts_1 = require("antlr4ts");
const ThrowingErrorListener_1 = require("../ThrowingErrorListener");
test('Boolean Literal', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", "true"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.literal();
    expect(context).toBeInstanceOf(ApexParser_1.LiteralContext);
    expect(context.BooleanLiteral()).toBeTruthy();
    expect(context.BooleanLiteral().text).toBe("true");
});
test('Expression', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", "a * 5"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.expression();
    expect(context).toBeInstanceOf(ApexParser_1.Arth1ExpressionContext);
    const arthExpression = context;
    expect(arthExpression.expression().length).toBe(2);
});
test('Compilation Unit', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", "public class Hello {}"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.compilationUnit();
    expect(context.typeDeclaration).toBeTruthy();
});
test('Compilation Unit (case insensitive)', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", "Public CLASS Hello {}"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.compilationUnit();
    expect(context.typeDeclaration).toBeTruthy();
});
test('Compilation Unit (bug test)', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", `public class Hello {
        public testMethod void func() {
            System.runAs(u) {
            }
        }
    }`));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.compilationUnit();
    expect(context.typeDeclaration).toBeTruthy();
});
test('Compilation Unit (inline SOQL)', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", `public class Hello {
        public void func() {
            List<Account> accounts = [Select Id from Accounts];
        }
    }`));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.compilationUnit();
    expect(context.typeDeclaration).toBeTruthy();
});
test('Compilation Unit (throwing errors)', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.cls", "public class Hello {"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    parser.removeErrorListeners();
    parser.addErrorListener(new ThrowingErrorListener_1.ThrowingErrorListener());
    try {
        parser.compilationUnit();
        expect(true).toBe(false);
    }
    catch (ex) {
        expect(ex).toBeInstanceOf(ThrowingErrorListener_1.SyntaxException);
    }
});
test('Trigger Unit', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.trigger", "trigger test on Account (before update, after update) {}"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.triggerUnit();
    expect(context).toBeTruthy();
});
test('SOQL Query', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.soql", "Select Id from Account"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.query();
    expect(context).toBeTruthy();
});
test('SOQL Query Using Field function', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.soql", "Select Fields(All) from Account"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.query();
    expect(context).toBeTruthy();
});
test('SOSL Query', () => {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream("test.sosl", "[Find {something} RETURNING Account]"));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    const context = parser.soslLiteral();
    expect(context).toBeTruthy();
});
//# sourceMappingURL=ApexParserTest.js.map