"use strict";
/*
 [The "BSD licence"]
 Copyright (c) 2020 Kevin Jones
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
 3. The name of the author may not be used to endorse or promote products
    derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.check = exports.ParseTreeWalker = exports.CommonTokenStream = void 0;
const path_1 = require("path");
const dir = require("node-dir");
const ApexLexer_1 = require("./ApexLexer");
const ApexParser_1 = require("./ApexParser");
const CaseInsensitiveInputStream_1 = require("./CaseInsensitiveInputStream");
const antlr4ts_1 = require("antlr4ts");
const ThrowingErrorListener_1 = require("./ThrowingErrorListener");
const fs_1 = require("fs");
const fs_2 = require("fs");
__exportStar(require("./ApexLexer"), exports);
__exportStar(require("./ApexParser"), exports);
__exportStar(require("./CaseInsensitiveInputStream"), exports);
__exportStar(require("./ThrowingErrorListener"), exports);
__exportStar(require("./ApexParserListener"), exports);
__exportStar(require("./ApexParserVisitor"), exports);
var antlr4ts_2 = require("antlr4ts");
Object.defineProperty(exports, "CommonTokenStream", { enumerable: true, get: function () { return antlr4ts_2.CommonTokenStream; } });
var ParseTreeWalker_1 = require("antlr4ts/tree/ParseTreeWalker");
Object.defineProperty(exports, "ParseTreeWalker", { enumerable: true, get: function () { return ParseTreeWalker_1.ParseTreeWalker; } });
function check() {
    const path = (0, path_1.resolve)(process.argv[1] || process.cwd());
    dir.files(path, function (err, files) {
        if (err)
            throw err;
        let parsedCount = 0;
        files.filter(name => name.endsWith(".cls")).forEach(file => {
            if ((0, fs_2.lstatSync)(file).isFile()) {
                const content = (0, fs_1.readFileSync)(file);
                const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream(file, content.toString()));
                const tokens = new antlr4ts_1.CommonTokenStream(lexer);
                const parser = new ApexParser_1.ApexParser(tokens);
                parser.removeErrorListeners();
                parser.addErrorListener(new ThrowingErrorListener_1.ThrowingErrorListener());
                try {
                    parser.compilationUnit();
                }
                catch (err) {
                    console.log(`Error parsing ${file}`);
                    console.log(err);
                }
                parsedCount += 1;
            }
        });
        console.log(`Parsed ${parsedCount} files`);
    });
}
exports.check = check;
//# sourceMappingURL=index.js.map